[devel] Imported from libpng-1.5.2beta03.tar
diff --git a/LICENSE b/LICENSE
index c7f1379..eb4ad62 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, February 19, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, March 3, 2011, are
 Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 19, 2011
+March 3, 2011
diff --git a/README b/README
index 96cca88..3eb8059 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.2beta03 - February 19, 2011 (shared library 15.0)
+README for libpng version 1.5.2beta03 - March 3, 2011 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/libpng-manual.txt b/libpng-manual.txt
index d31d130..8d2c204 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.2beta03 - February 19, 2011
+ libpng version 1.5.2beta03 - March 3, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.2beta03 - February 19, 2011
+ libpng versions 0.97, January 1998, through 1.5.2beta03 - March 3, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -2295,6 +2295,8 @@
 data.  See the Compression Library (zlib.h and algorithm.txt, distributed
 with zlib) for details on the compression levels.
 
+    #include zlib.h
+
     /* set the zlib compression level */
     png_set_compression_level(png_ptr,
         Z_BEST_COMPRESSION);
@@ -3284,6 +3286,7 @@
 files larger than just storing the raw bitmap.  You can specify the
 compression level by calling:
 
+    #include zlib.h
     png_set_compression_level(png_ptr, level);
 
 Another useful one is to reduce the memory level used by the library.
@@ -3294,12 +3297,14 @@
 data being emitted in smaller stored blocks, with a correspondingly
 larger relative overhead of up to 15% in the worst case.
 
+    #include zlib.h
     png_set_compression_mem_level(png_ptr, level);
 
 The other functions are for configuring zlib.  They are not recommended
 for normal use and may result in writing an invalid PNG file.  See
 zlib.h for more information on what these mean.
 
+    #include zlib.h
     png_set_compression_strategy(png_ptr,
         strategy);
 
@@ -4156,7 +4161,7 @@
 
 XIV. Y2K Compliance in libpng
 
-February 19, 2011
+March 3, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index d4565c3..c04a23f 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "February 19, 2011"
+.TH LIBPNG 3 "March 3, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.2beta03
 .SH SYNOPSIS
@@ -923,7 +923,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.2beta03 - February 19, 2011
+ libpng version 1.5.2beta03 - March 3, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -934,7 +934,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.2beta03 - February 19, 2011
+ libpng versions 0.97, January 1998, through 1.5.2beta03 - March 3, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -3218,6 +3218,8 @@
 data.  See the Compression Library (zlib.h and algorithm.txt, distributed
 with zlib) for details on the compression levels.
 
+    #include zlib.h
+
     /* set the zlib compression level */
     png_set_compression_level(png_ptr,
         Z_BEST_COMPRESSION);
@@ -4207,6 +4209,7 @@
 files larger than just storing the raw bitmap.  You can specify the
 compression level by calling:
 
+    #include zlib.h
     png_set_compression_level(png_ptr, level);
 
 Another useful one is to reduce the memory level used by the library.
@@ -4217,12 +4220,14 @@
 data being emitted in smaller stored blocks, with a correspondingly
 larger relative overhead of up to 15% in the worst case.
 
+    #include zlib.h
     png_set_compression_mem_level(png_ptr, level);
 
 The other functions are for configuring zlib.  They are not recommended
 for normal use and may result in writing an invalid PNG file.  See
 zlib.h for more information on what these mean.
 
+    #include zlib.h
     png_set_compression_strategy(png_ptr,
         strategy);
 
@@ -5079,7 +5084,7 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-February 19, 2011
+March 3, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -5328,7 +5333,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.2beta03 - February 19, 2011:
+Libpng version 1.5.2beta03 - March 3, 2011:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5351,7 +5356,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, February 19, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, March 3, 2011, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5450,7 +5455,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 19, 2011
+March 3, 2011
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 3eef05d..a4b77ab 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "February 19, 2011"
+.TH LIBPNGPF 3 "March 3, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.2beta03
 (private functions)
diff --git a/png.5 b/png.5
index 8a5fdea..93e5760 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "February 19, 2011"
+.TH PNG 5 "March 3, 2011"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 3a16b8b..b992850 100644
--- a/png.c
+++ b/png.c
@@ -555,13 +555,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.2beta03 - February 19, 2011" PNG_STRING_NEWLINE \
+     "libpng version 1.5.2beta03 - March 3, 2011" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.2beta03 - February 19, 2011\
+      return "libpng version 1.5.2beta03 - March 3, 2011\
       Copyright (c) 1998-2011 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 8d73678..42aab5a 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.2beta03 - February 19, 2011
+libpng version 1.5.2beta03 - March 3, 2011
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index c732074..54712b6 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.2beta03 - February 19, 2011
+ * libpng version 1.5.2beta03 - March 3, 2011
  *
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 7ad2a0c..255d08f 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.5.2beta03 - February 19, 2011
+Makefiles for  libpng version 1.5.2beta03 - March 3, 2011
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/png.h b/png.h
index 82b4d79..c5e869a 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.2beta03 - February 19, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.2beta03 - February 19, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -179,7 +179,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, February 19, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -291,7 +291,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    February 19, 2011
+ *    March 3, 2011
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -355,7 +355,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.2beta03"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.2beta03 - February 19, 2011\n"
+     " libpng version 1.5.2beta03 - March 3, 2011\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.2beta03 - February 19, 2011
+ * libpng version 1.5.2beta03 - March 3, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.2beta03 - February 19, 2011: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.2beta03 - March 3, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -179,7 +179,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, February 19, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.2beta03, March 3, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5